@@ -335,7 +335,7 @@ class Client(commandServer, encrypt, Desktop):
         excludePaths = " ".join(map(
             lambda x: '--exclude="/%s"' % x.replace('"', "").replace(
                 "'", ""),
-            skipPaths + deletePaths + skipList))
+            skipPaths + deletePaths + list(skipList)))
         if sync == "login":
             if os.path.exists(userHome) and \
                     os.path.exists(remoteProfile):
